pub struct TranscriptBuilder { /* private fields */ }Implementations
Sourceimpl TranscriptBuilder
impl TranscriptBuilder
pub fn with_params<F>(self, params: ParamResolver, f: F) -> Selfwhere
F: Fn(Self) -> Self,
pub fn add_protocol_patter<F: Field, S: Protocol<F>>(self, key: &S::Key) -> Self
pub fn add_reduction_patter<F: Field, S: Reduction<F>>( self, key: &S::Key, ) -> Self
pub fn new(vars: usize, params: ParamResolver) -> Self
pub fn round<F: Field, T: Any + Message<F>, const N: usize>(self) -> Self
pub fn point(self) -> Self
Sourcepub fn fold_rounds<F: Field, T: Any + Message<F>, const N: usize>(self) -> Self
pub fn fold_rounds<F: Field, T: Any + Message<F>, const N: usize>(self) -> Self
Adds V rounds for the V variables in the transcript for split and fold protocols which send one message per variable.
pub fn finish<F: Field, S: Duplex<F>>(self) -> TranscriptDescriptor<F, S>
pub fn repeat<const N: usize, M: Fn(Self, usize) -> Self>(self, f: M) -> Self