TranscriptGuard

Struct TranscriptGuard 

pub struct TranscriptGuard<'a, F: Field, S: Duplex<F>, P> { /* private fields */ }
Wraps transcript and proof, ensuring no message circumvents the transcript.

Implementations

Source

impl<'a, F: Field, S: Duplex<F>, P> TranscriptGuard<'a, F, S, P>

pub fn print_state(&self)

Prints the current state of the sponge, for debugging.

pub fn new(transcript: &'a mut Transcript<F, S>, proof: P) -> Self

pub fn new_guard<P2>( &mut self, proof: impl Into<MessageGuard<P2>>, ) -> TranscriptGuard<'_, F, S, P2>

pub fn receive_message<M, Q, const N: usize>( &mut self, query: Q, ) -> Result<(M, [F; N]), Error>
where M: Message<F> + 'static, Q: Fn(&P) -> M,

Allows to extract messages from the proof, absorbing them in the transcript automatically, also returning the corresponding challenges.

pub fn receive_message_delayed<M, Q>(&mut self, query: Q) -> MessageGuard<M>
where M: 'static, Q: FnOnce(&P) -> M,

similar to receive_message, doesn’t interact with the sponge in any way and returns a guarded value to be unwrapped later.

pub fn unwrap_guard<I: Message<F> + 'static, const N: usize>( &mut self, instance: MessageGuard<I>, ) -> Result<(I, [F; N]), Error>

unwraps the instance while absorbing it and also returning challenges.

pub fn unwrap_instance_unsafe<I>(&mut self, instance: MessageGuard<I>) -> I

Unwraps the instance while ignoring the transcript, caller must ensure that not including the instance is acceptable. Will still ultimately fail if the instance was expected in the pattern.

pub fn point(&mut self) -> Result<Vec<F>, Error>

generates a multivariate point